@@ -21,7 +21,6 @@
 # SOFTWARE.
 #
 ####################
-from __future__ import unicode_literals
 import logging
 import socket
 import threading
@@ -112,7 +111,7 @@ class ADUtils(object):
         7: "2016"
     }
 
-    xml_sid_rex = re.compile('<UserId>(S-[0-9\-]+)</UserId>')
+    xml_sid_rex = re.compile('<UserId>(S-[0-9\\-]+)</UserId>')
     xml_logontype_rex = re.compile('<LogonType>([A-Za-z0-9]+)</LogonType>')
 
     @staticmethod
@@ -355,6 +354,8 @@ class ADUtils(object):
         converting empty values to the default specified. This is primarily
         for output to JSON
         """
+        if entry is None:
+            return default
         try:
             if raw:
                 value = entry['raw_attributes'][prop]
@@ -411,10 +412,14 @@ class ADUtils(object):
         """
         if isinstance(data, bytes):
             data = repr(data)
+        elif isinstance(data, list):
+            data = list(map(lambda x: repr(x) if isinstance(x, bytes) else x,data))
         return data
 
     @staticmethod
     def is_filtered_container(containerdn):
+        if not containerdn:
+            return False
         if "CN=DOMAINUPDATES,CN=SYSTEM,DC=" in containerdn.upper():
             return True
         if "CN=POLICIES,CN=SYSTEM,DC=" in containerdn.upper() and (containerdn.upper().startswith('CN=USER') or containerdn.upper().startswith('CN=MACHINE')):
@@ -423,6 +428,8 @@ class ADUtils(object):
 
     @staticmethod
     def is_filtered_container_child(containerdn):
+        if not containerdn:
+            return False
         if "CN=PROGRAM DATA,DC=" in containerdn.upper():
             return True
         if "CN=SYSTEM,DC=" in containerdn.upper():
@@ -431,6 +438,10 @@ class ADUtils(object):
 
     @staticmethod
     def parse_gplink_string(linkstr):
+        '''
+        Parse GP Link string according to MS-GPOL
+        https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-gpol/08090b22-bc16-49f4-8e10-f27a8fb16d18
+        '''
         if not linkstr:
             return
         for links in linkstr.split('LDAP://')[1:]:
